@@ -7,26 +7,28 @@ A wrapper for Trackmania.io api service.
 :license: MIT, see LICENSE for more details.
 """
 import asyncio
+import logging
 import os
 
-from .api import *
+from .ad import *
 from .config import *
-from .constants import *
+from .cotd import *
 from .errors import *
-from .structures.ad import *
-from .structures.cotd import *
-from .structures.map import *
-from .structures.medal_times import *
-from .structures.player import *
+from .matchmaking import *
+from .player import *
+from .tmmap import *
+from .totd import *
+from .trophy import *
 
 __title__ = "py-tmio"
 __author__ = "Deepesh Nimma"
 __license__ = "MIT"
 __copyright__ = "Copyright 2022-present Deepesh Nimma"
-__version__ = "0.3.1"
+__version__ = "v0.3.2"
 
 __path__ = __import__("pkgutil").extend_path(__path__, __name__)
 
-
 if os.name == "nt":
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+
+logging.getLogger(__name__).addHandler(logging.NullHandler())
