@@ -1,3 +1,4 @@
+import logging
 from typing import Optional
 
 import aiohttp
@@ -5,11 +6,14 @@ import aiohttp
 from .config import Client
 from .errors import NoUserAgentSetError
 
-__all__ = ("ResponseCodeError", "APIClient")
+__all__ = ("ResponseCodeError", "_APIClient")
+_log = logging.getLogger(__name__)
 
 
 class ResponseCodeError(ValueError):
     """
+    .. versionadded:: 0.3.0
+
     Raised when a non-OK HTTP Response is received
 
     Parameters
@@ -41,8 +45,12 @@ class ResponseCodeError(ValueError):
 
 
 # pylint: disable=W0612
-class APIClient:
-    """API Wrappers"""
+class _APIClient:
+    """
+    .. versionadded:: 0.3.0
+
+    API Wrappers
+    """
 
     def __init__(self, **session_kwargs):
         if Client.USER_AGENT is None:
@@ -68,9 +76,15 @@ class APIClient:
         if should_raise and response.status >= 400:
             try:
                 response_json = await response.json()
+                if "error" in response_json:
+                    return
+                await self.session.close()
                 raise ResponseCodeError(response=response, response_json=response_json)
             except aiohttp.ContentTypeError as content_type_error:
                 response_text = await response.text()
+                if "error" in response_text:
+                    return
+                await self.session.close()
                 raise ResponseCodeError(
                     response=response, response_text=response_text
                 ) from content_type_error
@@ -81,28 +95,29 @@ class APIClient:
         endpoint: str,
         *,
         raise_for_status: bool = True,
-        ratelimit: bool = False,
         **kwargs,
     ) -> dict:
         """Send an HTTP request to the site API and return the JSON response."""
         async with self.session.request(method.upper(), endpoint, **kwargs) as resp:
             await self.maybe_raise_for_status(resp, raise_for_status)
-
-            if not ratelimit:
-                return await resp.json()
-            else:
-                return (
-                    await resp.json(),
-                    int(resp.headers.get("x-ratelimit-remaining")[0]),
-                    int(resp.headers.get("x-ratelimit-limit")[0]),
-                )
+            _log.info(f"Sending {method.upper()} to {endpoint}")
+            try:
+                if "trackmania.io" in endpoint:
+                    Client.RATELIMIT_LIMIT = int(
+                        resp.headers.get("x-ratelimit-limit")[0]
+                    )
+                    Client.RATELIMIT_REMAINING = int(
+                        resp.headers.get("x-ratelimit-remaining")[0]
+                    )
+            except (AttributeError, TypeError):
+                pass
+            return await resp.json()
 
     async def get(
         self,
         endpoint: str,
         *,
         raise_for_status: bool = True,
-        ratelimit: bool = False,
         **kwargs,
     ) -> dict:
         """Site API GET."""
@@ -110,7 +125,6 @@ class APIClient:
             "GET",
             endpoint,
             raise_for_status=raise_for_status,
-            ratelimit=ratelimit,
             **kwargs,
         )
 
