@@ -1,10 +1,12 @@
-from redis import Redis
+import redis
 
 __all__ = ("Client",)
 
-# pylint: disable=too-few-public-methods
+
 class Client:
     """
+    .. versionadded:: 0.3.0
+
     Client class to manage user defined constants
 
     Parameters
@@ -17,12 +19,16 @@ class Client:
         The port of the redis server.
     REDIS_DB : int
         The database of the redis server.
+        .. versionadded:: 0.2.0
     REDIS_PASSWORD : str
         The password of the redis server.
+        .. versionadded:: 0.2.0
     RATELIMIT_LIMIT: int
         The `trackmania.io` ratelimit limit.
+        .. versionadded:: 0.2.1
     RATELIMIT_REMAINING : int
         The amount of remaining requests with `trackmania.io` api.
+        .. versionadded:: 0.2.1
     """
 
     USER_AGENT: str = None
@@ -33,3 +39,20 @@ class Client:
 
     RATELIMIT_LIMIT: int = 40
     RATELIMIT_REMAINING: int = None
+
+    @staticmethod
+    def _get_cache_client() -> redis.Redis:
+        """
+        Gets the Cache Client
+
+        Returns
+        -------
+        :class:`redis.Redis`
+            The cache_client
+        """
+        return redis.Redis(
+            host=Client.REDIS_HOST,
+            port=Client.REDIS_PORT,
+            db=Client.REDIS_DB,
+            password=Client.REDIS_PASSWORD,
+        )
