@@ -1,11 +1,12 @@
-# pylint: disable=too-many-instance-attributes
 from typing import List
 
-__all__ = ("TMIO", "TMX")
 
-# pylint: disable=too-few-public-methods
-class TMIOTabs:
-    """TMIO Endpoints"""
+class _TMIOTabs:
+    """
+    .. versionadded:: 0.3.0
+
+    _TMIO Endpoints
+    """
 
     def __init__(self):
         self.PLAYER: str = "player"
@@ -13,8 +14,10 @@ class TMIOTabs:
         self.TROPHIES: str = "trophies"
         self.MAP: str = "map"
         self.LEADERBOARD: str = "leaderboard"
+        self.MATCHES: str = "matches"
 
-        self.TOP_MATCHMAKING: str = "top/matchmaking"
+        self.TOP_MATCHMAKING: str = "top/matchmaking/2"
+        self.TOP_ROYAL: str = "top/matchmaking/3"
         self.TOP_TROPHIES: str = "top/trophies"
 
         self.MATCHMAKING_ID: int = 2
@@ -25,10 +28,11 @@ class TMIOTabs:
         self.ADS: str = "ads"
 
 
-# pylint: disable=too-few-public-methods
-class TMIO:
+class _TMIO:
     """
-    Basic TMIO Api Details
+    .. versionadded:: 0.3.0
+
+    Basic _TMIO Api Details
 
     Parameters
     ----------
@@ -38,7 +42,7 @@ class TMIO:
         The BASE url for the api. Equal to "trackmania.io"
     api : str
         The api endpoint for `trackmania.io`. Equal to "api".
-    TABS : :class:`TMIOTabs`
+    TABS : :class:`_TMIOTabs`
         The TABS for the api.
     """
 
@@ -46,11 +50,11 @@ class TMIO:
     BASE: str = "trackmania.io"
     API: str = "api"
 
-    TABS: TMIOTabs = TMIOTabs()
+    TABS: _TMIOTabs = _TMIOTabs()
 
     @staticmethod
     def build(endpoints: List[str]) -> str:
-        """Builds a TMIO endpoint url.
+        """Builds a _TMIO endpoint url.
 
         Parameters
         ----------
@@ -63,12 +67,14 @@ class TMIO:
             The built endpoint url.
 
         """
-        url = f"{TMIO.PROTOCOL}://{TMIO.BASE}/{TMIO.API}/"
+        url = f"{_TMIO.PROTOCOL}://{_TMIO.BASE}/{_TMIO.API}/"
 
         if len(endpoints) == 0:
             return url
         if len(endpoints) > 1:
             for item in endpoints:
+                if isinstance(item, int):
+                    item = str(item)
                 url = url + item + "/"
 
             # Removing the Final /
@@ -76,10 +82,11 @@ class TMIO:
         return url + endpoints[0]
 
 
-# pylint: disable=too-few-public-methods
-class TMX:
+class _TMX:
     """
-    Basic TMX Api Details
+    .. versionadded:: 0.3.0
+
+    Basic _TMX Api Details
 
     Parameters
     ----------
@@ -98,7 +105,7 @@ class TMX:
 
     @staticmethod
     def build(endpoints: List[str]) -> str:
-        """URL Builder for TMX API
+        """URL Builder for _TMX API
 
         Parameters
         ----------
@@ -110,12 +117,14 @@ class TMX:
         str
             The URL.
         """
-        url = f"{TMX.PROTOCOL}://{TMX.BASE}/{TMX.API}/"
+        url = f"{_TMX.PROTOCOL}://{_TMX.BASE}/{_TMX.API}/"
 
         if len(endpoints) == 0:
             return url
         if len(endpoints) > 1:
             for item in endpoints:
+                if isinstance(item, int):
+                    item = str(item)
                 url = url + item + "/"
 
             # Removing the Final /
