@@ -1,8 +1,12 @@
 __all__ = (
     "TrackmaniaException",
+    "TMIOException",
+    "InvalidPlayerException",
     "NoUserAgentSetError",
     "InvalidUsernameError",
     "InvalidIDError",
+    "InvalidTrophyNumber",
+    "InvalidTOTDDate",
 )
 
 
@@ -13,20 +17,20 @@ class TrackmaniaException(Exception):
     pass
 
 
+class TMIOException(Exception):
+    """BASE exception class for errors from trackmania.io"""
+
+    pass
+
+
 class InvalidPlayerException(TrackmaniaException):
-    """ """
+    """Base Exception class for Player-Related exceptions"""
 
-    def __init__(self, *args):
-        if args:
-            message = args[0]
-        else:
-            message = None
-
-        super().__init__(message)
+    pass
 
 
 class NoUserAgentSetError(Exception):
-    """ """
+    """Raised when a User-Agent is not set."""
 
     def __init__(self):
         message = "No User Agent has been set.\nPlease read the README for instructions on how to set the USER_AGENT."
@@ -34,7 +38,7 @@ class NoUserAgentSetError(Exception):
 
 
 class InvalidUsernameError(InvalidPlayerException):
-    """ """
+    """Raised when a username is not valid."""
 
     def __init__(self, *args):
         if args:
@@ -46,19 +50,7 @@ class InvalidUsernameError(InvalidPlayerException):
 
 
 class InvalidIDError(InvalidPlayerException):
-    """ """
-
-    def __init__(self, *args):
-        if args:
-            message = args[0]
-        else:
-            message = None
-
-        super().__init__(message)
-
-
-class InvalidMatchmakingGroupError(TrackmaniaException):
-    """ """
+    """Raised when an Invalid ID is given."""
 
     def __init__(self, *args):
         if args:
@@ -79,3 +71,15 @@ class InvalidTrophyNumber(TrackmaniaException):
             message = None
 
         super().__init__(message)
+
+
+class InvalidTOTDDate(TrackmaniaException):
+    """Raised when an invalid TOTD Date is given."""
+
+    def __init__(self, *args):
+        if args:
+            message = args[0]
+        else:
+            message = None
+
+        super().__init__(message)
